@@ -11,26 +11,24 @@ rule <- function(data, x) {
 }
 
 sub <-
-    lmtp_sub(sim_cens, a, "Y", nodes, baseline = NULL,
-             cens, k = 0, shift = rule,
-             outcome_type = "binomial",
-             folds = 2)
-
-set.seed(553)
+  sw(lmtp_sub(sim_cens, a, "Y", nodes, baseline = NULL,
+              cens, k = 0, shift = rule,
+              outcome_type = "binomial",
+              folds = 2))
 
 ipw <-
-  lmtp_ipw(sim_cens, a, "Y", NULL, nodes,
-           cens, k = 0, shift = rule, folds = 10)
+  sw(lmtp_ipw(sim_cens, a, "Y", NULL, nodes,
+              cens, k = 0, shift = rule, folds = 2))
 
 tmle <-
-    lmtp_tmle(sim_cens, a, "Y", nodes, baseline = NULL,
+    sw(lmtp_tmle(sim_cens, a, "Y", nodes, baseline = NULL,
               cens, k = 0, shift = rule,
-              outcome_type = "binomial", folds = 2)
+              outcome_type = "binomial", folds = 2))
 
 sdr <-
-  lmtp_sdr(sim_cens, a, "Y", nodes, baseline = NULL,
+  sw(lmtp_sdr(sim_cens, a, "Y", nodes, baseline = NULL,
            cens, k = 0, shift = rule,
-           outcome_type = "binomial", folds = 2)
+           outcome_type = "binomial", folds = 2))
 
 # tests
 test_that("estimator fidelity with censoring", {
